@@ -1,25 +1,28 @@
 import requests
+import importlib
 from urllib.parse import unquote
 
 from rest_framework.exceptions import PermissionDenied
 from django.conf import settings
 
-__all__ = ('CredentialMixin', )
+
+__all__ = ('CredentialMixin', 'SmartAdminRequiredMixin', )
 
 
-class CredentialMixin(object):
+class BaseCredentialMixin(object):
+
     if settings.DASHBOARD_URL.endswith("/"):
         url = settings.DASHBOARD_URL
     else:
         url = settings.DASHBOARD_URL + '/'
 
-    def get_user_info(self, request, get_token=False):
-        if get_token:
+    def get_user_info(self, request):
+        if 'token' in request.GET and "platform_id" in request.GET:
             token = unquote(request.GET["token"])
-        else:
-            if 'HTTP_AUTHORIZATION' not in request.META or "platform_id" not in request.GET:
-                raise PermissionDenied({"status": "error", "message": "you don't have permission to access"})
+        elif 'HTTP_AUTHORIZATION' not in request.META and "platform_id" in request.GET:
             token = request.META["HTTP_AUTHORIZATION"]
+        else:
+            raise PermissionDenied({"status": "error", "message": "you don't have permission to access"})
         try:
             response = requests.get(f"{self.url}api/check-platform/?platform_id={request.GET['platform_id']}",
                                     headers={"executetoken": token})
@@ -31,6 +34,21 @@ class CredentialMixin(object):
 
         return response.json()["auth_info"]
 
+    def get_check_admin(self, request, *args, **kwargs):
+        user_info = self.get_user_info(request, *args, **kwargs)
+        user_id = user_info["id"]
+        if user_id in (19, 22, 23, 55):
+            return user_id
+        raise PermissionDenied({"status": "error", "message": "This endpoint only for smart admin users."})
+
+
+class CredentialMixin(BaseCredentialMixin):
+
+    check_credential = True
+    with_settings_model = False # add for support old versions
+    if hasattr(settings, 'CREDENTIAL_MODEL'):
+        with_settigns_model = True
+    
     # method for dashboard app
     def get_check_dash_auth(self, request):
         if 'HTTP_EXECUTETOKEN' not in request.META:
@@ -42,28 +60,53 @@ class CredentialMixin(object):
 
         return auth_info["is_admin"]
 
-    def get_check_admin(self, request, *args, **kwargs):
-        user_info = self.get_user_info(request, *args, **kwargs)
-        user_id = user_info["id"]
-        if user_id in (19, 22, 23, 55):
-            return user_id
-        return False
+    def get_credential(self, request, model=None):
+        """[summary]
+
+        Arguments:
+            request {HttpRequest} -- django http request
+
+        Keyword Arguments:
+            model {django model or None} -- django model (default: {None})
+
+        Raises:
+            PermissionDenied: if not credential exists
+
+        Returns:
+            django model -- credential object
+        """
+        if not model:
+            model = self.get_credential_model()
 
-    def get_credential(self, request, model, check_user=False):
-        # check user deprecated
-        user_info = self.get_user_info(request)
-        user_id = user_info["id"]
         cred_id = request.GET.get("credential_id")
 
         params = {
             'id': cred_id,
         }
-        if check_user:
-            params['user_id'] = user_id
 
         credential = model.objects.filter(**params).first()
-
         if not credential:
             raise PermissionDenied({"status": "error", "message": "Credential does not exist."})
 
         return credential
+
+    def initial(self, request, *args, **kwargs):
+        user_info = self.get_user_info(request)
+        self.smart_user_id = user_info['id']
+        self.smart_username = user_info['username']
+        if self.with_settings_model and self.check_credential:
+            self.credential = self.get_credential(request)
+        return super().initial(request, *args, **kwargs)
+
+    def get_credential_model(self):
+        if hasattr(settings, 'CREDENTIAL_MODEL'):
+            module_path, model = settings.CREDENTIAL_MODEL.rsplit('.', 1)
+            module = importlib.import_module(module_path) 
+            return getattr(module, model)
+        raise AttributeError('miss CREDENTIAL_MODEL in django settings')
+
+
+class SmartAdminRequiredMixin(BaseCredentialMixin):
+    def initial(self, request, *args, **kwargs):
+        self.get_check_admin(request)
+        return super().initial(request, *args, **kwargs)
\ No newline at end of file
