@@ -28,7 +28,7 @@ class LimitOffsetPaginationListAPIView(CredentialMixin, ListAPIView):
     self.date_form
     self.date_to
     """
-
+    check_credential = False
     limit = None
     offset = None
     pagination_class = StandardResultsPagination
@@ -43,13 +43,6 @@ class LimitOffsetPaginationListAPIView(CredentialMixin, ListAPIView):
         return date_from, date_to
 
     def _get_params(self):
-        admin = self.get_check_admin(self.request)
-        if not admin:
-            raise PermissionDenied(
-                {"status": "error", "message": "this method for admin"}
-            )
-
-        # self._ensure_limit_offset_params()
         self.integration_id = self.request.GET.get("integration_id")
         last_week = self.request.GET.get("last_week", "")
         last_3_days = self.request.GET.get("last_3_days", "")
@@ -78,7 +71,6 @@ class LimitOffsetPaginationListAPIView(CredentialMixin, ListAPIView):
 
     def list(self, request, format=None):
         self._get_params()
-        print(self.limit)
         self._ensure_limit_param()
         queryset = self.get_queryset()
         page = self.paginate_queryset(queryset)
